"""productionize downloads

Revision ID: 5a19a365d596
Revises: 13091b732388
Create Date: 2022-12-01 14:47:50.619153

"""
from alembic import op


# revision identifiers, used by Alembic.
revision = "5a19a365d596"
down_revision = "13091b732388"
branch_labels = None
depends_on = None


old_state_machine = """{"workflow_name": "test_download"}"""
new_state_machine = """{"workflow_name": "download"}"""


old_script = """#!/bin/sh
set -o errexit
chmod 770 .
./productfetcher --product-locator $1
./deliver -r . --prefix $2
"""

new_script = """#!/bin/sh
set -o errexit
chmod 770 .

{{^multiple_fetch}}./productfetcher --for-download --product-locator $2{{/multiple_fetch}}
{{#multiple_fetch}}./productfetcher --for-download{{product_locator}}{{/multiple_fetch}}

{{^create_tar_file}}./deliver -r . --prefix $1{{/create_tar_file}}
{{#create_tar_file}}./deliver --tar -r . --prefix $1{{/create_tar_file}}
"""

old_condor_args = """arguments = {{product_locator}} {{request_id}}"""
new_condor_args = """arguments = {{request_id}} {{product_locator}}"""


def upgrade():
    # update capabilities
    op.execute(
        """
        INSERT INTO capabilities (capability_name, max_jobs, enabled, has_image_products, paused, start_state, requires_qa, single_version_only)
        SELECT 'download' as capability_name,
        max_jobs,
        enabled,
        has_image_products,
        paused,
        start_state,
        requires_qa,
        single_version_only
        FROM capabilities
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        INSERT INTO capability_states (capability_name, state)
        SELECT 'download' as capability_name,
        state
        FROM capability_states
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE capability_state_transitions
        SET capability_name = 'download'
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE capability_state_machines
        SET capability_name = 'download'
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_machines
        SET associated_workflows = '{new_state_machine}'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_executions
        SET capability_name = 'download'
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE capability_versions
        SET capability_name = 'download'
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE capability_requests
        SET capability_name = 'download'
        WHERE capability_name = 'test_download'
        """
    )
    # remove old name
    op.execute(
        """
        DELETE FROM capability_states
        WHERE capability_name = 'test_download'
        """
    )
    op.execute(
        """
        DELETE FROM capabilities
        WHERE capability_name = 'test_download'
        """
    )

    # update workflows
    op.execute(
        """
        INSERT INTO workflows (workflow_name, uses_casa, requires_lustre, remote_capable, external_wf)
        SELECT 'download' as workflow_name,
        uses_casa,
        requires_lustre,
        remote_capable,
        external_wf
        FROM workflows
        WHERE workflow_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE workflow_requests
        SET workflow_name = 'download'
        WHERE workflow_name = 'test_download'
        """
    )
    op.execute(
        """
        UPDATE workflow_templates
        SET workflow_name = 'download'
        WHERE workflow_name = 'test_download'
        """
    )
    # remove old name
    op.execute(
        """
        DELETE FROM workflows
        WHERE workflow_name = 'test_download'
        """
    )

    # update workflow templates
    op.execute(
        """
        UPDATE workflow_templates
        SET filename = 'download.sh'
        WHERE filename = 'test_download.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{new_script}'
        WHERE filename = 'download.sh'
        """
    )
    op.execute(
        """
        UPDATE workflow_templates
        SET filename = 'download.condor'
        WHERE filename = 'test_download.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), 'test_download', 'download')::bytea
        WHERE filename = 'download.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{old_condor_args}', E'{new_condor_args}')::bytea
        WHERE filename = 'download.condor'
        """
    )


def downgrade():
    # downgrade capabilities
    op.execute(
        """
        INSERT INTO capabilities (capability_name, max_jobs, enabled, has_image_products, paused, start_state, requires_qa, single_version_only)
        SELECT 'test_download' as capability_name,
        max_jobs,
        enabled,
        has_image_products,
        paused,
        start_state,
        requires_qa,
        single_version_only
        FROM capabilities
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        INSERT INTO capability_states (capability_name, state) 
        SELECT 'test_download' as capability_name,
        state
        FROM capability_states
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_state_transitions
        SET capability_name = 'test_download'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_state_machines
        SET capability_name = 'test_download'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        f"""
        UPDATE capability_state_machines
        SET associated_workflows = '{old_state_machine}'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_executions
        SET capability_name = 'test_download'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_versions
        SET capability_name = 'test_download'
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE capability_requests
        SET capability_name = 'test_download'
        WHERE capability_name = 'download'
        """
    )
    # remove old name
    op.execute(
        """
        DELETE FROM capability_states
        WHERE capability_name = 'download'
        """
    )
    op.execute(
        """
        DELETE FROM capabilities
        WHERE capability_name = 'download'
        """
    )

    # downgrade workflows
    op.execute(
        """
        INSERT INTO workflows (workflow_name, uses_casa, requires_lustre, remote_capable, external_wf) 
        SELECT 'test_download' as workflow_name,
        uses_casa,
        requires_lustre,
        remote_capable,
        external_wf
        FROM workflows
        WHERE workflow_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE workflow_requests
        SET workflow_name = 'test_download'
        WHERE workflow_name = 'download'
        """
    )
    op.execute(
        """
        UPDATE workflow_templates
        SET workflow_name = 'test_download'
        WHERE workflow_name = 'download'
        """
    )
    op.execute(
        """
        DELETE FROM workflows
        WHERE workflow_name = 'download'
        """
    )

    # update workflow templates
    op.execute(
        """
        UPDATE workflow_templates
        SET filename = 'test_download.sh'
        WHERE filename = 'download.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_script}'
        WHERE filename = 'test_download.sh'
        """
    )
    op.execute(
        """
        UPDATE workflow_templates
        SET filename = 'test_download.condor'
        WHERE filename = 'download.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), 'download', 'test_download')::bytea
        WHERE filename = 'test_download.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{new_condor_args}', E'{old_condor_args}')::bytea
        WHERE filename = 'download.condor'
        """
    )
