# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update download workflow templates to use PEXes

Revision ID: 5b0ad8236e2a
Revises: 83ea8e91a420
Create Date: 2021-05-13 13:38:54.812422

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "5b0ad8236e2a"
down_revision = "83ea8e91a420"
branch_labels = None
depends_on = None


def upgrade():

    shell_script_content = """#!/bin/sh
./datafetcher --product-locator $1
./deliver -r . --prefix $2
"""

    op.execute(
        "UPDATE workflow_templates " f"SET content = E'{shell_script_content}' " "WHERE filename = 'test_download.sh'"
    )

    submit_file_content = """executable = test_download.sh
arguments = {{product_locator}} {{request_id}}

output = test_download.out
error = test_download.err
log = test_download.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/datafetcher, $(SBIN_PATH)/deliver

queue
"""

    op.execute(
        "UPDATE workflow_templates "
        f"SET content = E'{submit_file_content}' "
        "WHERE filename = 'test_download.condor'"
    )


def downgrade():
    op.execute(
        "UPDATE workflow_templates "
        "SET content = E'#!/bin/sh\n\ndatafetcher --product-locator $1\ndeliver -r . --prefix $2\n' "
        "WHERE filename = 'test_download.sh'"
    )

    op.execute(
        "UPDATE workflow_templates "
        "SET content = E'executable = test_download.sh\narguments = {{product_locator}} {{request_id}}\nerror = test_download.err\nlog = test_download.log\n\nqueue' "
        "WHERE filename = 'test_download.condor'"
    )
